@@ -161,6 +161,9 @@ static GtkActionEntry actions_file[] = {
   { "ActionFileCloseAll", GTK_STOCK_CLOSE, N_("Close All"), "<shift><control>w",
 	N_("Close all files"),
     G_CALLBACK (on_close_all_file_activate)},
+  { "ActionFileCloseOther", GTK_STOCK_CLOSE, N_("Close Other"), "<shift><control>o",
+	N_("Close other documents"),
+    G_CALLBACK (on_close_other_file_activate)},	
   { "ActionFileReload", GTK_STOCK_REVERT_TO_SAVED, N_("Reload F_ile"), NULL,
 	N_("Reload current file"),
     G_CALLBACK (on_reload_file_activate)},
@@ -920,7 +923,6 @@ update_status (DocmanPlugin *plugin, IAnjutaEditor *te)
 		if (status == NULL)
 			return;
 		
-		zoom = anjuta_preferences_get_int (plugin->prefs, TEXT_ZOOM_FACTOR);
 		line = ianjuta_editor_get_lineno (te, NULL);
 		col = ianjuta_editor_get_column (te, NULL);
 			
@@ -934,7 +936,10 @@ update_status (DocmanPlugin *plugin, IAnjutaEditor *te)
 		}
 		
 		if (IANJUTA_IS_EDITOR_ZOOM(te))
+		{
+			zoom = anjuta_preferences_get_int (plugin->prefs, TEXT_ZOOM_FACTOR);
 			anjuta_status_set_default (status, _("Zoom"), "%d", zoom);
+		}
 		else
 			anjuta_status_set_default (status, _("Zoom"), NULL);
 		
